@@ -5,7 +5,7 @@ use super::{
 	DateSerde,
 	DateTimeSerde,
 	DateTimeSerdeOpt,
-	enums::{InverterMode, OperationMode, SiteStatus, TimeUnit},
+	enums::{InverterMode, MeterType, OperationMode, SiteStatus, TimeUnit},
 };
 
 #[derive(Debug, Deserialize)]
@@ -69,7 +69,7 @@ pub struct Site {
 	pub peak_power: f64,
 	#[serde(with = "DateTimeSerde")]
 	pub last_update_time: NaiveDateTime,
-	pub currency: String,
+	pub currency: Option<String>,
 	#[serde(with = "DateTimeSerde")]
 	pub installation_date: NaiveDateTime,
 	#[serde(with = "DateTimeSerdeOpt")]
@@ -293,6 +293,28 @@ pub struct SiteStorageDataTop {
 	pub storage_data: SiteStorageData,
 }
 
+#[derive(Debug, Deserialize)]
+pub struct GasEmissionsSaved {
+	pub units: String,
+	pub co2: f64,
+	pub so2: f64,
+	pub nox: f64,
+}
+
+#[derive(Debug, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct SiteEnvBenefits {
+	pub gas_emission_saved: GasEmissionsSaved,
+	pub trees_planted: f64,
+	pub light_bulbs: f64,
+}
+
+#[derive(Debug, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct SiteEnvBenefitsTop {
+	pub env_benefits: SiteEnvBenefits,
+}
+
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Meter {
@@ -368,6 +390,31 @@ pub struct SiteInventoryTop {
 	pub inventory: SiteInventory,
 }
 
+#[derive(Debug, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct SiteMeterValueExt {
+	pub meter_serial_number: String,
+	#[serde(rename = "connectedSolaredgeDeviceSN")]
+	pub connected_solaredge_device_sn: String,
+	pub model: String,
+	pub meter_type: MeterType,
+	pub values: Vec<SiteDateValue>,
+}
+
+#[derive(Debug, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct SiteMeters {
+	pub time_unit: TimeUnit,
+	pub unit: String,
+	pub meters: Vec<SiteMeterValueExt>,
+}
+
+#[derive(Debug, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct SiteMetersTop {
+	pub meter_energy_details: SiteMeters,
+}
+
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Equipment {
