@@ -4,7 +4,7 @@ use url::Url;
 /// Adapter to allow different HTTP clients to be used with the library, to properly implement this
 /// trait, use [async_trait](https://crates.io/crates/async-trait).
 #[async_trait]
-pub trait HttpClientAdapter: Default {
+pub trait HttpClientAdapter {
 	/// Error type used by the underlying HTTP library
 	type Error;
 
